# kop
![pypi](https://img.shields.io/pypi/v/kop.svg)
![versions](https://img.shields.io/pypi/pyversions/kop.svg)

Modern python kubernetes operators

## Usage

```console
> pip install kop
```

## Getting Started

- [Development](./docs/DEVELOPMENT.md)
  - [setup](./docs/DEVELOPMENT.md#setup)
  - [check](./docs/DEVELOPMENT.md#check)
  - [dream2nix](./docs/DEVELOPMENT.md#dream2nix)
  - [pypi](./docs/DEVELOPMENT.md#pypi)

## License

`kop` is released under the [MIT license](./LICENSE)
